@@ -80,6 +80,11 @@ BEAM::BEAM (GLOBALDATA *global, ENVIRONMENT *env, double xpos, double ypos, int
   setEnvironment (env);
   _align = LEFT;
   _global = global;
+  #ifdef NETWORK
+  char buffer[256];
+  sprintf(buffer, "BEAM %d %d %d %d", (int) xpos, (int) ypos, fireAngle, weaponType);
+  global->Send_To_Clients(buffer);
+  #endif
   x = xpos;
   y = ypos;
   angle = fireAngle % 360;
